@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,9 +26,7 @@
  *
  ************************************************************************/
 
-#ifndef _STREAM_HXX //autogen
 #include <tools/stream.hxx>
-#endif
 #include "sbx.hxx"
 #include <vector>
 using namespace std;
@@ -315,7 +314,6 @@ void SbxArray::Remove( SbxVariable* pVar )
         for( UINT32 i = 0; i < pData->size(); i++ )
         {
             SbxVariableRef* pRef = (*pData)[i];
-            // SbxVariableRef* pRef = pData->GetObject( i );
             if( *pRef == pVar )
             {
                 Remove32( i ); break;
@@ -382,7 +380,7 @@ SbxVariable* SbxArray::FindUserData( UINT32 nData )
             {
                 p = pVar;
                 p->ResetFlag( SBX_EXTFOUND );
-                break;	// JSM 06.10.95
+                break;
             }
             // Haben wir ein Array/Objekt mit Extended Search?
             else if( pVar->IsSet( SBX_EXTSEARCH ) )
@@ -781,3 +779,5 @@ BOOL SbxDimArray::StoreData( SvStream& rStrm ) const
 }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
