@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -55,7 +55,6 @@
 #include <unotools/localfilehelper.hxx>
 #include <bf_so3/svstor.hxx>
 
-#include "docinf.hxx"
 #include "fltfnc.hxx"
 #include "docfac.hxx"
 #include "cfgmgr.hxx"
@@ -75,7 +74,7 @@
 #include "objuno.hxx"
 #include "request.hxx"
 
-#include <legacysmgr/legacy_binfilters_smgr.hxx>	//STRIP002 
+#include <legacysmgr/legacy_binfilters_smgr.hxx>
 
 #include "bf_basic/basmgr.hxx"
 
@@ -92,11 +91,11 @@ using namespace ::com::sun::star::uno;
 
 //====================================================================
 
-/*?*/ GDIMetaFile* SfxObjectShell::GetPreviewMetaFile( sal_Bool bFullContent ) const
-/*?*/ {DBG_BF_ASSERT(0, "STRIP"); return NULL;//STRIP001 
+/*?*/ GDIMetaFile* SfxObjectShell::GetPreviewMetaFile( sal_Bool /*bFullContent*/ ) const
+/*?*/ { return NULL;
 /*?*/ }
 
-/*N*/ FASTBOOL SfxObjectShell::SaveWindows_Impl( SvStorage &rStor ) const
+/*N*/ bool SfxObjectShell::SaveWindows_Impl( SvStorage & /*rStor*/ ) const
 /*N*/ {
 /*N*/ 		return FALSE;
 /*N*/ }
@@ -112,7 +111,7 @@ using namespace ::com::sun::star::uno;
 /*N*/ 	{
 /*N*/ 		SfxDocumentInfo &rDocInfo = GetDocInfo();
 /*N*/ 		rDocInfo.SetTemplateConfig( HasTemplateConfig() );
-/*N*/ 
+/*N*/
 /*N*/ 		if ( IsModified() )
 /*N*/ 		{
 /*N*/ 			// Keine Unterschiede mehr zwischen Save, SaveAs
@@ -125,25 +124,25 @@ using namespace ::com::sun::star::uno;
 /*N*/                 	aCreated.SetName( String() );
 /*N*/                 	rDocInfo.SetCreated( aCreated );
 /*N*/             	}
-/*N*/ 
+/*N*/
 /*N*/             	SfxStamp aPrinted = rDocInfo.GetPrinted();
 /*N*/             	if ( aUserName == aPrinted.GetName() )
 /*N*/             	{
 /*N*/                 	aPrinted.SetName( String() );
 /*N*/                 	rDocInfo.SetPrinted( aPrinted );
 /*N*/             	}
-/*N*/ 
+/*N*/
 /*N*/ 				aUserName.Erase();
 /*N*/         	}
-/*N*/ 
+/*N*/
 /*N*/ 			rDocInfo.SetChanged( aUserName );
 /*N*/ 			if ( !HasName() || pImp->bIsSaving )
 /*N*/ 				UpdateTime_Impl( rDocInfo );
 /*N*/ 		}
-/*N*/ 
+/*N*/
 /*N*/ 		if ( !pImp->bIsSaving )
 /*N*/ 			rDocInfo.SetPasswd( pImp->bPasswd );
-/*N*/ 
+/*N*/
 /*N*/ 		Broadcast( SfxDocumentInfoHint( &rDocInfo ) );
 /*N*/ 	}
 /*N*/ }
@@ -154,11 +153,11 @@ using namespace ::com::sun::star::uno;
 /*N*/ {
 /*N*/ 	//Demnaechst mal gemeinsame Teile zusammenfassen
 /*N*/ 	UpdateDocInfoForSave();
-/*N*/ 
+/*N*/
 /*N*/ #if !defined( SFX_KEY_MAXPREVIEWSIZE ) && defined( TFPLUGCOMM )
 /*N*/ #define SFX_KEY_MAXPREVIEWSIZE SFX_KEY_ISFREE
 /*N*/ #endif
-/*N*/ 
+/*N*/
 /*N*/ #ifdef MI_doch_wieder_die_alte_preview
 /*N*/ 	String aMaxSize = SFX_INIMANAGER()->Get( SFX_KEY_MAXPREVIEWSIZE );
 /*N*/ 	ULONG nMaxSize = aMaxSize.Len() ? ULONG( aMaxSize ) : 50000;
@@ -167,7 +166,7 @@ using namespace ::com::sun::star::uno;
 /*N*/ #endif
 /*N*/ 	if( nMaxSize && !GetDocInfo().IsPasswd() &&
 /*N*/ 		SFX_CREATE_MODE_STANDARD == eCreateMode )
-/*N*/ 	{DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ 	{
 /*N*/ 	}
 
 /*N*/ 	if( pImp->bIsSaving )
@@ -180,7 +179,7 @@ using namespace ::com::sun::star::uno;
 /*N*/ 		{
 /*N*/ 			SfxDocumentInfo& rDocInfo = GetDocInfo();
 /*N*/ 			rDocInfo.Save(pNewStg);
-/*N*/ 
+/*N*/
 /*N*/ 			// wenn es sich um ein Dokument lokales Basic handelt, dieses
 /*N*/ 			// schreiben
 /*N*/ 			if ( pImp->pBasicMgr )
@@ -207,36 +206,15 @@ using namespace ::com::sun::star::uno;
                         pNewStg );
 /*N*/ #endif
 /*N*/ 			}
-/*N*/ 
+/*N*/
 /*N*/ 			// Windows-merken
 /*N*/ 			if ( TRUE ) HACK(aus config)
 /*N*/ 				SaveWindows_Impl( *pNewStg );
-/*N*/ 
+/*N*/
 /*N*/ 			// Konfiguration schreiben
 /*N*/ 			if ( GetConfigManager() )
 /*N*/ 			{
-/* //!MBA
-                if ( rDocInfo.HasTemplateConfig() )
-                {
-                    const String aTemplFileName( rDocInfo.GetTemplateFileName() );
-                    if ( aTemplFileName.Len() )
-                    {
-                        INetURLObject aURL( aTemplFileName );
-                        DBG_ASSERT( aURL.GetProtocol() != INET_PROT_NOT_VALID, "Illegal URL !" );
-
-                        SvStorageRef aStor = new SvStorage( aURL.GetMainURL( INetURLObject::NO_DECODE ) );
-                        if ( SVSTREAM_OK == aStor->GetError() )
-                        {
-                            GetConfigManager()->StoreConfiguration(aStor);
-                            if (aRef->IsStream(SfxConfigManager::GetStreamName()))
-                                aRef->Remove(SfxConfigManager::GetStreamName());
-                        }
-                    }
-                }
-                else
- */
 /*N*/ 				{
-//! MBA                    GetConfigManager()->SetModified( TRUE );
 /*?*/                     GetConfigManager()->StoreConfiguration( pNewStg );
 /*N*/ 				}
 /*N*/ 			}
@@ -245,18 +223,15 @@ using namespace ::com::sun::star::uno;
 /*N*/ 	}
 /*N*/ 	else
 /*N*/ 	{
-/*N*/ 		//!! kein Aufruf der Basisklasse wegen doppeltem Aufruf in Persist
-/*N*/ 		//if(!SfxObjectShell::SaveAs(pNewStg))
-/*N*/ 		//  return FALSE;
-/*N*/ 		SfxApplication *pSfxApp = SFX_APP();
-/*N*/ 		SfxMedium *pActMed = GetMedium();
-/*N*/ 
+/*N*/ 		/*SfxApplication *pSfxApp =*/ SFX_APP();
+/*N*/ 		/*SfxMedium *pActMed =*/ GetMedium();
+/*N*/
 /*N*/ 		// alte DocInfo laden
 /*N*/ 		SfxDocumentInfo &rDocInfo = GetDocInfo();
-/*N*/ 
+/*N*/
 /*N*/ 		// DocInfo speichern
 /*N*/ 		rDocInfo.Save( pNewStg );
-/*N*/ 
+/*N*/
 /*N*/ 		// wenn es sich um ein Dokument lokales Basic handelt, dieses schreiben
 /*N*/ 		if ( pImp->pBasicMgr )
 /*N*/             pImp->pBasicMgr->Store(
@@ -285,36 +260,15 @@ using namespace ::com::sun::star::uno;
 /*N*/ 		// Windows-merken
 /*N*/ 		if ( TRUE ) HACK(aus config)
 /*N*/ 			SaveWindows_Impl( *pNewStg );
-/*N*/ 
+/*N*/
 /*N*/ 		// Konfiguration schreiben
 /*N*/ 		if (GetConfigManager())
 /*N*/ 		{
-/* //!MBA
-            if ( rDocInfo.HasTemplateConfig() )
-            {
-                const String aTemplFileName( rDocInfo.GetTemplateFileName() );
-                if ( aTemplFileName.Len() )
-                {
-                    INetURLObject aURL( aTemplFileName );
-                    DBG_ASSERT( aURL.GetProtocol() != INET_PROT_NOT_VALID, "Illegal URL !" );
-
-                    SvStorageRef aStor = new SvStorage( aURL.GetMainURL( INetURLObject::NO_DECODE ) );
-                    if ( SVSTREAM_OK == aStor->GetError() )
-                    {
-                        GetConfigManager()->StoreConfiguration(aStor);
-                        if (pNewStg->IsStream(SfxConfigManager::GetStreamName()))
-                            pNewStg->Remove(SfxConfigManager::GetStreamName());
-                    }
-                }
-            }
-            else
- */
 /*N*/ 			{
-//!MBA                GetConfigManager()->SetModified( TRUE );
 /*?*/                 GetConfigManager()->StoreConfiguration(pNewStg);
             }
 /*N*/ 		}
-/*N*/ 
+/*N*/
 /*N*/ 		return TRUE;
 /*N*/ 	}
 /*N*/ }
@@ -326,24 +280,24 @@ using namespace ::com::sun::star::uno;
 /*N*/ {
 /*N*/ 	// Get old time from documentinfo
 /*N*/ 	Time aOldTime(rInfo.GetTime());
-/*N*/ 
+/*N*/
 /*N*/ 	// Initialize some local member! Its neccessary for wollow operations!
 /*N*/ 	DateTime	aNow					;	// Date and time at current moment
 /*N*/ 	Time		n24Time		(24,0,0,0)	;	// Time-value for 24 hours - see follow calculation
 /*N*/ 	ULONG		nDays		= 0			;	// Count of days between now and last editing
 /*N*/ 	Time		nAddTime	(0)			;	// Value to add on aOldTime
-/*N*/ 
+/*N*/
 /*N*/ 	// Safe impossible cases!
 /*N*/ 	// User has changed time to the past between last editing and now ... its not possible!!!
 /*N*/ 	DBG_ASSERT( !(aNow.GetDate()<pImp->nTime.GetDate()), "Timestamp of last change is in the past ?!..." );
-/*N*/ 
+/*N*/
 /*N*/ 	// Do the follow only, if user has NOT changed time to the past.
 /*N*/ 	// Else add a time of 0 to aOldTime ... !!!
 /*N*/ 	if (aNow.GetDate()>=pImp->nTime.GetDate())
 /*N*/ 	{
 /*N*/ 		// Get count of days last editing.
 /*N*/ 		nDays = aNow.GetSecFromDateTime(pImp->nTime.GetDate())/86400 ;
-/*N*/ 
+/*N*/
 /*N*/ 		if (nDays==0)
 /*N*/ 		{
 /*N*/ 			// If no day between now and last editing - calculate time directly.
@@ -361,28 +315,14 @@ using namespace ::com::sun::star::uno;
 /*?*/ 			nAddTime	+=	n24Time-(const Time&)pImp->nTime		;
 /*?*/ 			nAddTime	+=	aNow					;
 /*N*/ 		}
-/*N*/ 
+/*N*/
 /*N*/ 		aOldTime += nAddTime;
 /*N*/ 	}
-/*N*/ 
+/*N*/
 /*N*/ 	rInfo.SetTime(aOldTime.GetTime());
 /*N*/ 	pImp->nTime = aNow;
 /*N*/ 	rInfo.IncDocumentNumber();
 /*N*/ 	//! DocumentNummer
-/*N*/ #if 0
-/*N*/ 	const String aDocNo(rInfo.GetUserKey(0).GetWord());
-/*N*/ 	const String aTitle(rInfo.GetUserKey(0).GetTitle());
-/*N*/ 	USHORT nNo = 1;
-/*N*/ 	if ( aDocNo.Len() )
-/*N*/ 	{
-/*N*/ 		nNo = (USHORT)aDocNo;
-/*N*/ 		if(nNo)
-/*N*/ 			++nNo;
-/*N*/ 		else
-/*N*/ 			nNo = 1;
-/*N*/ 	}
-/*N*/ 	rInfo.SetUserKey(SfxDocUserKey(aTitle, nNo), 0);
-/*N*/ #endif
 /*N*/ 	return rInfo;
 /*N*/ }
 
@@ -390,11 +330,10 @@ using namespace ::com::sun::star::uno;
 
 /*?*/ SvEmbeddedInfoObject* SfxObjectShell::InsertObject
 /*?*/ (
-/*?*/ 	SvEmbeddedObject*   pObj,
-/*?*/ 	const String&       rName
+/*?*/ 	SvEmbeddedObject*   /*pObj*/,
+/*?*/ 	const String&       /*rName*/
 /*?*/ )
-
-/*?*/ {DBG_BF_ASSERT(0, "STRIP"); return NULL;//STRIP001 
+/*?*/ { return NULL;
 /*?*/ }
 
 //-------------------------------------------------------------------------
@@ -403,12 +342,12 @@ using namespace ::com::sun::star::uno;
 /*N*/ {
 /*N*/     if ( !pImp->pCfgMgr )
 /*N*/     {
-/*N*/         if ( bForceCreation || HasStorage() && SfxConfigManager::HasConfiguration( *GetStorage() ) )
+/*N*/         if ( bForceCreation || (HasStorage() && SfxConfigManager::HasConfiguration( *GetStorage() )) )
 /*N*/ 		{
 /*N*/             pImp->pCfgMgr = new SfxConfigManager( *this );
 /*N*/ 		}
 /*N*/     }
-/*N*/ 
+/*N*/
 /*N*/ 	return pImp->pCfgMgr;
 /*N*/ }
 
@@ -418,10 +357,10 @@ using namespace ::com::sun::star::uno;
 /*N*/ {
 /*N*/ //    if ( pImp->pCfgMgr == SFX_CFGMANAGER() && pMgr)
 /*N*/ //        pMgr->Activate(pImp->pCfgMgr);
-/*N*/ 
+/*N*/
 /*N*/     if ( pImp->pCfgMgr && pImp->pCfgMgr != pMgr )
 /*?*/ 		delete pImp->pCfgMgr;
-/*N*/ 
+/*N*/
 /*N*/ 	pImp->pCfgMgr = pMgr;
 /*N*/ }
 
@@ -443,41 +382,28 @@ using namespace ::com::sun::star::uno;
 
 //--------------------------------------------------------------------
 
-/*N*/ USHORT SfxObjectShell::GetContentCount(USHORT nIdx1,
-/*N*/ 										 USHORT nIdx2)
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); return 0;//STRIP001 
+/*N*/ USHORT SfxObjectShell::GetContentCount(USHORT /*nIdx1*/,
+/*N*/ 										 USHORT /*nIdx2*/)
+/*N*/ { return 0;
 /*N*/ }
 
 //--------------------------------------------------------------------
 
-/*N*/ void SfxObjectShell::GetContent(String &rText,
-/*N*/ 								Bitmap &rClosedBitmap,
-/*N*/ 								Bitmap &rOpenedBitmap,
-/*N*/ 								BOOL &bCanDel,
-/*N*/ 								USHORT i,
-/*N*/ 								USHORT nIdx1,
-/*N*/ 								USHORT nIdx2 )
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
-/*N*/ }
-
-//--------------------------------------------------------------------
-
-/*N*/ void   SfxObjectShell::GetContent(String &rText,
-/*N*/ 								  Bitmap &rClosedBitmap,
-/*N*/ 								  Bitmap &rOpenedBitmap,
-/*N*/ 								  BmpColorMode eColorMode,
-/*N*/ 								  BOOL &bCanDel,
-/*N*/ 								  USHORT i,
-/*N*/ 								  USHORT nIdx1,
-/*N*/ 								  USHORT nIdx2 )
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ void SfxObjectShell::GetContent(String & /*rText*/,
+/*N*/ 								Bitmap & /*rClosedBitmap*/,
+/*N*/ 								Bitmap & /*rOpenedBitmap*/,
+/*N*/ 								BOOL & /*bCanDel*/,
+/*N*/ 								USHORT /*i*/,
+/*N*/ 								USHORT /*nIdx1*/,
+/*N*/ 								USHORT /*nIdx2*/ )
+/*N*/ {
 /*N*/ }
 
 //--------------------------------------------------------------------
 
 /*N*/ void SfxObjectShell::LoadStyles
 /*N*/ (
-    SfxObjectShell &rSource         /*  die Dokument-Vorlage, aus der
+    SfxObjectShell &/*rSource*/         /*  die Dokument-Vorlage, aus der
                                             die Styles geladen werden sollen */
 /*N*/ )
 
@@ -491,7 +417,7 @@ using namespace ::com::sun::star::uno;
     rufen.
 */
 
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ {
 /*N*/ }
 
 //--------------------------------------------------------------------
@@ -506,7 +432,7 @@ using namespace ::com::sun::star::uno;
 /*N*/ 			pImp->pEventConfig->Connect( pImp->pCfgMgr );
 /*N*/ 		pImp->pEventConfig->Initialize();
 /*N*/ 	}
-/*N*/ 
+/*N*/
 /*N*/ 	return pImp->pEventConfig;
 /*N*/ }
 
