@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,14 +28,10 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 
-
 #include <string.h>
 #include <stdio.h>
 
-#ifndef GCC
-#endif
-
-#include <tools/solar.h>
+#include <bf_svtools/bf_solar.h>
 #include <bf_svtools/itempool.hxx>
 #include "whassert.hxx"
 #include <bf_svtools/brdcst.hxx>
@@ -205,8 +202,9 @@ SvStream &SfxItemPool::Store(SvStream &rStream) const
         SfxMultiMixRecordWriter aWhichIdsRec( &rStream, SFX_ITEMPOOL_REC_WHICHIDS, 0 );
 
         // erst Atomaren-Items und dann die Sets schreiben (wichtig beim Laden)
-        for ( pImp->bInSetItem = FALSE; pImp->bInSetItem <= TRUE && !rStream.GetError(); ++pImp->bInSetItem )
+        for ( int ft = 0; ft < 2 && !rStream.GetError(); ft++)
         {
+            pImp->bInSetItem = ft != 0;
             SfxPoolItemArray_Impl **pArr = pImp->ppPoolItems;
             SfxPoolItem **ppDefItem = ppStaticDefaults;
             const USHORT nSize = GetSize_Impl();
@@ -407,7 +405,7 @@ void SfxItemPool::readTheItems (
         nLastSurrogate = nSurrogate;
 
         // Ref-Count und Item laden
-        USHORT nRef;
+        USHORT nRef(0);
         rStream >> nRef;
 
         pItem = pDefItem->Create(rStream, nVersion);
@@ -610,7 +608,7 @@ SvStream &SfxItemPool::Load(SvStream &rStream)
         for ( USHORT nVerNo = 0; aVerRec.GetContent(); ++nVerNo )
         {
             // Header f"ur einzelne Version einlesen
-            USHORT nVersion, nHStart, nHEnd;
+            USHORT nVersion(0), nHStart(0), nHEnd(0);
             rStream >> nVersion >> nHStart >> nHEnd;
             USHORT nCount = nHEnd - nHStart + 1;
 
@@ -619,6 +617,7 @@ SvStream &SfxItemPool::Load(SvStream &rStream)
             {
                 // neue Version hinzufuegen
                 USHORT *pMap = new USHORT[nCount];
+                memset(pMap, 0, nCount * sizeof(USHORT));
                 for ( USHORT n = 0; n < nCount; ++n )
                     rStream >> pMap[n];
                 SetVersionMap( nVersion, nHStart, nHEnd, pMap );
@@ -628,15 +627,14 @@ SvStream &SfxItemPool::Load(SvStream &rStream)
     }
 
     // Items laden
-    FASTBOOL bSecondaryLoaded = FALSE;
+    bool bSecondaryLoaded = FALSE;
     long nSecondaryEnd = 0;
     {
         SfxMultiRecordReader aWhichIdsRec( &rStream, SFX_ITEMPOOL_REC_WHICHIDS);
         while ( aWhichIdsRec.GetContent() )
         {
             // SlotId, Which-Id und Item-Version besorgen
-            USHORT nCount, nVersion, nWhich;
-            //!USHORT nSlotId = aWhichIdsRec.GetContentTag();
+            USHORT nCount(0), nVersion(0), nWhich(0);
             rStream >> nWhich;
             if ( pImp->nLoadingVersion != pImp->nVersion )
                 // Which-Id aus File-Version in Pool-Version verschieben
@@ -648,10 +646,6 @@ SvStream &SfxItemPool::Load(SvStream &rStream)
 
             rStream >> nVersion;
             rStream >> nCount;
-            //!SFX_ASSERTWARNING( !nSlotId || !HasMap() ||
-            //!			( nSlotId == GetSlotId( nWhich, FALSE ) ) ||
-            //!			!GetSlotId( nWhich, FALSE ),
-            //!			nWhich, "Slot/Which mismatch" );
 
             USHORT nIndex = GetIndex_Impl(nWhich);
             SfxPoolItemArray_Impl **ppArr = pImp->ppPoolItems + nIndex;
@@ -688,8 +682,7 @@ SvStream &SfxItemPool::Load(SvStream &rStream)
         while ( aDefsRec.GetContent() )
         {
             // SlotId, Which-Id und Item-Version besorgen
-            USHORT nVersion, nWhich;
-            //!USHORT nSlotId = aDefsRec.GetContentTag();
+            USHORT nVersion(0), nWhich(0);
             rStream >> nWhich;
             if ( pImp->nLoadingVersion != pImp->nVersion )
                 // Which-Id aus File-Version in Pool-Version verschieben
@@ -700,8 +693,6 @@ SvStream &SfxItemPool::Load(SvStream &rStream)
                 continue;
 
             rStream >> nVersion;
-            //!SFX_ASSERTWARNING( !HasMap() || ( nSlotId == GetSlotId( nWhich, FALSE ) ),
-            //!			nWhich, "Slot/Which mismatch" );
 
             // Pool-Default-Item selbst laden
             SfxPoolItem *pItem =
@@ -741,7 +732,7 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
         CHECK_FILEFORMAT( rStream, SFX_ITEMPOOL_TAG_STARTPOOL_4 );
         rStream >> pImp->nMajorVer >> pImp->nMinorVer;
     }
-    sal_uInt32 nAttribSize;
+    sal_uInt32 nAttribSize(0);
     int bOwnPool = TRUE;
     UniString aExternName;
     if ( pImp->nMajorVer > 1 || pImp->nMinorVer >= 2 )
@@ -774,7 +765,7 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
     ULONG nStartPos = rStream.Tell();
     rStream.SeekRel( nAttribSize );
     CHECK_FILEFORMAT( rStream, SFX_ITEMPOOL_TAG_SIZES );
-    sal_uInt32 nSizeTableLen;
+    sal_uInt32 nSizeTableLen(0);
     rStream >> nSizeTableLen;
     sal_Char *pBuf = new sal_Char[nSizeTableLen];
     rStream.Read( pBuf, nSizeTableLen );
@@ -786,18 +777,18 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
     {
         // Version-Map finden (letztes ULONG der Size-Table gibt Pos an)
         rStream.Seek( nEndOfSizes - sizeof(sal_uInt32) );
-        sal_uInt32 nVersionMapPos;
+        sal_uInt32 nVersionMapPos(0);
         rStream >> nVersionMapPos;
         rStream.Seek( nVersionMapPos );
 
         // Versions-Maps einlesen
         CHECK_FILEFORMAT( rStream, SFX_ITEMPOOL_TAG_VERSIONMAP );
-        USHORT nVerCount;
+        USHORT nVerCount(0);
         rStream >> nVerCount;
         for ( USHORT nVerNo = 0; nVerNo < nVerCount; ++nVerNo )
         {
             // Header f"ur einzelne Version einlesen
-            USHORT nVersion, nHStart, nHEnd;
+            USHORT nVersion(0), nHStart(0), nHEnd(0);
             rStream >> nVersion >> nHStart >> nHEnd;
             USHORT nCount = nHEnd - nHStart + 1;
             USHORT nBytes = (nCount)*sizeof(USHORT);
@@ -807,6 +798,7 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
             {
                 // neue Version hinzufuegen
                 USHORT *pMap = new USHORT[nCount];
+                memset(pMap, 0, nCount * sizeof(USHORT));
                 for ( USHORT n = 0; n < nCount; ++n )
                     rStream >> pMap[n];
                 SetVersionMap( nVersion, nHStart, nHEnd, pMap );
@@ -820,9 +812,9 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
     // Items laden
     rStream.Seek( nStartPos );
     CHECK_FILEFORMAT( rStream, SFX_ITEMPOOL_TAG_ITEMS );
-    FASTBOOL bSecondaryLoaded = FALSE;
+    bool bSecondaryLoaded = FALSE;
     long nSecondaryEnd = 0;
-    USHORT nWhich, nSlot;
+    USHORT nWhich(0), nSlot(0);
     while ( rStream >> nWhich, nWhich )
     {
         // ggf. Which-Id aus alter Version verschieben?
@@ -833,8 +825,8 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
         USHORT nMappedWhich = GetWhich(nSlot, FALSE);
         int bKnownItem = bOwnPool || IsWhich(nMappedWhich);
 
-        USHORT nRef, nCount, nVersion;
-        sal_uInt32 nAttrSize;
+        USHORT nRef(0), nCount(0), nVersion(0);
+        sal_uInt32 nAttrSize(0);
         rStream >> nVersion >> nCount;
 
         SfxPoolItemArray_Impl **ppArr = 0;
@@ -845,11 +837,6 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
             if ( !bOwnPool )
                 nWhich = nMappedWhich;
 
-            //!SFX_ASSERTWARNING( !nSlot || !HasMap() ||
-            //!			( nSlot == GetSlotId( nWhich, FALSE ) ) ||
-            //!			!GetSlotId( nWhich, FALSE ),
-            //!			nWhich, "Slot/Which mismatch" );
-
             USHORT nIndex = GetIndex_Impl(nWhich);
             ppArr = pImp->ppPoolItems + nIndex;
             pNewArr = new SfxPoolItemArray_Impl( nCount );
@@ -956,7 +943,6 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
                                 SFX_TRACE( "reusing item", pOldItem );
                             }
                         }
-                        //! DBG_ASSERT( bFound, "old-item not found in file" );
                         if ( !bFound )
                         {
                             SFX_TRACE( "item not found: ", pOldItem );
@@ -984,8 +970,8 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
         int bKnownItem = bOwnPool || IsWhich(nMappedWhich);
 
         ULONG nPos = nLastPos;
-        sal_uInt32 nSize;
-        USHORT nVersion;
+        sal_uInt32 nSize(0);
+        USHORT nVersion(0);
         rStream >> nVersion;
 
         if ( bKnownItem )
@@ -1075,7 +1061,7 @@ const SfxPoolItem* SfxItemPool::LoadSurrogate
 
 {
     // erstmal das Surrogat lesen
-    USHORT nSurrogat;
+    USHORT nSurrogat(0);
     rStream >> nSurrogat;
 
     // direkt gespeichertes Item?
@@ -1093,7 +1079,7 @@ const SfxPoolItem* SfxItemPool::LoadSurrogate
     // auf jeden Fall aufgel"ost werden.
     if ( !pRefPool )
         pRefPool = this;
-    FASTBOOL bResolvable = pRefPool->GetName().Len() > 0;
+    bool bResolvable = pRefPool->GetName().Len() > 0;
     if ( !bResolvable )
     {
         // Bei einem anders aufgebauten Pool im Stream, mu\s die SlotId
@@ -1128,7 +1114,7 @@ const SfxPoolItem* SfxItemPool::LoadSurrogate
                             : 0;
                 if ( !pItem )
                 {
-                    DBG_ERROR( "can't resolve surrogate" );
+                    OSL_FAIL( "can't resolve surrogate" );
                     rWhich = 0; // nur zur Sicherheit fuer richtige Stream-Pos
                     return 0;
                 }
@@ -1156,7 +1142,7 @@ const SfxPoolItem* SfxItemPool::LoadSurrogate
 //-------------------------------------------------------------------------
 
 
-FASTBOOL SfxItemPool::StoreSurrogate
+bool SfxItemPool::StoreSurrogate
 (
     SvStream&			rStream,
     const SfxPoolItem* 	pItem
@@ -1169,7 +1155,7 @@ FASTBOOL SfxItemPool::StoreSurrogate
 
     [R"uckgabewert]
 
-    FASTBOOL				TRUE
+    bool				TRUE
                             es wurde ein echtes Surrogat gespeichert, auch
                             SFX_ITEMS_NULL bei 'pItem==0',
                             SFX_ITEMS_STATICDEFAULT und SFX_ITEMS_POOLDEFAULT
@@ -1184,7 +1170,7 @@ FASTBOOL SfxItemPool::StoreSurrogate
 {
     if ( pItem )
     {
-        FASTBOOL bRealSurrogate = IsItemFlag(*pItem, SFX_ITEM_POOLABLE);
+        bool bRealSurrogate = IsItemFlag(*pItem, SFX_ITEM_POOLABLE);
         rStream << ( bRealSurrogate
                         ? GetSurrogate( pItem )
                         : (UINT16) SFX_ITEMS_DIRECT );
@@ -1230,7 +1216,7 @@ USHORT SfxItemPool::GetSurrogate(const SfxPoolItem *pItem) const
 
 // -----------------------------------------------------------------------
 
-FASTBOOL SfxItemPool::IsInStoringRange( USHORT nWhich ) const
+bool SfxItemPool::IsInStoringRange( USHORT nWhich ) const
 {
     return nWhich >= pImp->nStoringStart &&
            nWhich <= pImp->nStoringEnd;
@@ -1445,14 +1431,14 @@ USHORT SfxItemPool::GetNewWhich
 // -----------------------------------------------------------------------
 
 
-FASTBOOL SfxItemPool::IsInVersionsRange( USHORT nWhich ) const
+bool SfxItemPool::IsInVersionsRange( USHORT nWhich ) const
 {
     return nWhich >= pImp->nVerStart && nWhich <= pImp->nVerEnd;
 }
 
 // -----------------------------------------------------------------------
 
-FASTBOOL SfxItemPool::IsCurrentVersionLoading() const
+bool SfxItemPool::IsCurrentVersionLoading() const
 
 /*	[Beschreibung]
 
@@ -1509,7 +1495,7 @@ USHORT SfxItemPool::GetLoadingVersion() const
 
 //-------------------------------------------------------------------------
 
-FASTBOOL SfxItemPool::IsVer2_Impl() const
+bool SfxItemPool::IsVer2_Impl() const
 {
     return pMaster->pImp->nMajorVer >= 2;
 }
@@ -1517,8 +1503,8 @@ FASTBOOL SfxItemPool::IsVer2_Impl() const
 //-------------------------------------------------------------------------
 
 
-FASTBOOL SfxItemPool::StoreItem( SvStream &rStream, const SfxPoolItem &rItem,
-                                 FASTBOOL bDirect ) const
+bool SfxItemPool::StoreItem( SvStream &rStream, const SfxPoolItem &rItem,
+                                 bool bDirect ) const
 
 /*	[Beschreibung]
 
@@ -1543,7 +1529,7 @@ FASTBOOL SfxItemPool::StoreItem( SvStream &rStream, const SfxPoolItem &rItem,
 
     [Querverweise]
 
-    <SfxItemPool::LoadItem(SvStream&,FASTBOOL)const>
+    <SfxItemPool::LoadItem(SvStream&,bool)const>
 */
 
 {
@@ -1583,13 +1569,13 @@ FASTBOOL SfxItemPool::StoreItem( SvStream &rStream, const SfxPoolItem &rItem,
 //-------------------------------------------------------------------------
 
 
-const SfxPoolItem* SfxItemPool::LoadItem( SvStream &rStream, FASTBOOL bDirect,
+const SfxPoolItem* SfxItemPool::LoadItem( SvStream &rStream, bool bDirect,
                                           const SfxItemPool *pRefPool )
 
 // pRefPool==-1 => nicht putten!
 
 {
-    USHORT nWhich, nSlot; // nSurrogate;
+    USHORT nWhich=0, nSlot=0; // nSurrogate;
     rStream >> nWhich >> nSlot;
 
     BOOL bDontPut = (SfxItemPool*)-1 == pRefPool;
@@ -1604,7 +1590,7 @@ const SfxPoolItem* SfxItemPool::LoadItem( SvStream &rStream, FASTBOOL bDirect,
         else
         {
             // WID in der Version nicht vorhanden => ueberspringen
-            USHORT nSurro, nVersion, nLen;
+            USHORT nSurro(0), nVersion(0), nLen(0);
             rStream >> nSurro;
             if ( SFX_ITEMS_DIRECT == nSurro )
             {
@@ -1616,7 +1602,7 @@ const SfxPoolItem* SfxItemPool::LoadItem( SvStream &rStream, FASTBOOL bDirect,
     }
 
     // wird eine andere Version geladen?
-    FASTBOOL bCurVersion = pRefPool->IsCurrentVersionLoading();
+    bool bCurVersion = pRefPool->IsCurrentVersionLoading();
     if ( !bCurVersion )
         // Which-Id auf neue Version mappen
         nWhich = pRefPool->GetNewWhich( nWhich );
@@ -1642,8 +1628,8 @@ const SfxPoolItem* SfxItemPool::LoadItem( SvStream &rStream, FASTBOOL bDirect,
     if ( bDirect || ( nWhich && !pItem ) )
     {
         // bDirekt bzw. nicht IsPoolable() => Item direkt laden
-        USHORT nVersion;
-        sal_uInt32 nLen;
+        USHORT nVersion(0);
+        sal_uInt32 nLen(0);
         rStream >> nVersion >> nLen;
         ULONG nIStart = rStream.Tell();
 
@@ -1678,3 +1664,5 @@ const SfxPoolItem* SfxItemPool::LoadItem( SvStream &rStream, FASTBOOL bDirect,
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
