@@ -414,7 +414,7 @@ void SwExcelParser::Parse()
                 break;
             // -----------------------------------------------------------
             default:
-                DBG_ERROR(
+                OSL_FAIL(
                 "*SwExcelParser::Parse(): Zustand undefiniert - Trottel!" );
             }
         pIn->SeekRel( nBytesLeft );		// nicht gelesene Bytes ueberlesen
@@ -424,97 +424,6 @@ void SwExcelParser::Parse()
 //  ::EndProgress( pExcGlob->pD->GetDocShell() );
 
     }
-/*
-// ---------------------------------------------- SwExcelParser::Parse() -
-void SwExcelParser::Parse()
-    {
-    ExcTabelle *pTab;
-    USHORT	nOpcode;			// aktueller Opcode
-    USHORT	nLaengeRec;			// Laenge aktueller Record
-    ULONG	nLastBof = 0;		// Stream Position vom letzten BOF
-
-//	ScanDokuInfos();
-    // jetzt ist aDataPool mit Daten zum importieren gefuellt
-
-
-    // BOF -> EOF => eine Tabelle
-    pTab = aExcDok.GetFirstTab();
-    while( pTab )
-        {
-        while( !pIn->IsEof() && eAktZust != ImpZustEnd )
-            {
-            *pIn >> nOpcode >> nLaengeRec;
-            nBytesLeft = nLaengeRec;
-
-            // Automat: Init -> [ Global ] -> TabBase -> Tab -> ...
-            switch( eAktZust )
-                {
-                // ----------------------- Tabelleninhalt --------------------
-                case ImpZustTab:
-                    {
-                    switch( nOpcode )
-                        {
-                        case 0x01:	Blank25(); break;		// BLANK		[ 2  5]
-                        case 0x03:	Number25(); break;		// NUMBER		[ 2  5]
-                        case 0x04:	Label25(); break;		// LABEL		[ 2  5]
-                        case 0x06:	Formula25(); break;		// FORMULA		[ 2  5]
-                        case 0x08:	Row25(); break;			// ROW			[ 2  5]
-                        case 0x0A:							// EOF			[ 2345]
-                            Eof();
-                            EndSheet();
-                            eAktZust = ImpZustEnd;
-                            break;
-                        case 0x1C:	Note(); break;			// NOTE			[ 2345]
-                        case 0x21:	Array25(); break;		// ARRAY		[ 2  5]
-                        case 0x7E:	Rk(); break;			// RK			[    5]
-                        case 0xBD:	Mulrk(); break;			// MULRK		[    5]
-                        case 0xBE:	Mulblank(); break;		// MULBLANK		[    5]
-                        case 0xD6:	Rstring(); break;		// RSTRING		[    5]
-                        case 0x0201: Blank34(); break;		// BLANK		[  34 ]
-                        case 0x0203: Number34(); break;		// NUMBER		[  34 ]
-                        case 0x0204: Label34(); break;		// LABEL		[  34 ]
-                        case 0x0206: Formula3(); break;		// FORMULA		[  3  ]
-                        case 0x0208: Row34(); break;		// ROW			[  34 ]
-                        case 0x0221: Array34(); break;		// ARRAY		[  34 ]
-                        case 0x027E: Rk(); break;			// RK			[  34 ]
-                        case 0x0406: Formula4(); break;		// FORMULA		[   4 ]
-                        case 0x04BC: Shrfmla(); break;		// SHRFMLA		[    5]
-                        }
-                    }
-                    break;
-                // ----------------------- Endzustand (nutzbar?) -------------
-                case ImpZustEnd:
-                    {
-                    //switch( nOpcode )
-                        {
-                        }
-                    }
-                    break;
-                // ----------------------- Record String folgt ---------------
-                case ImpZustString:
-                    {
-                    DBG_ASSERT( nOpcode == 0x07 || nOpcode == 0x0207,
-                    "+SwExcelParser::Read(): Formatfehler: Formula ohne String" );
-
-                    if( nOpcode == 0x07 || nOpcode == 0x0207 )
-                        REC_String();
-
-                    eAktZust = ImpZustTab;
-                    }
-                    break;
-                // ----------------------- Tabelleninhalt Init-Phase ---------
-                // -----------------------------------------------------------
-                default:
-                    DBG_ERROR(
-                    "*SwExcelParser::Read(): Zustand undefiniert - Trottel!" );
-                }
-            pIn->SeekRel( nBytesLeft );		// nicht gelesene Bytes ueberlesen
-            }
-        pTab = aExcDok.GetNextTab();
-        }
-
-    }
-*/
 
 
 
