@@ -30,8 +30,8 @@
 #include "formcellbinding.hxx"
 #endif
 
-#include <drafts/com/sun/star/form/XBindableValue.hpp>
-#include <drafts/com/sun/star/form/XListEntrySink.hpp>
+#include <com/sun/star/form/binding/XBindableValue.hpp>
+#include <com/sun/star/form/binding/XListEntrySink.hpp>
 #include <com/sun/star/drawing/XDrawPageSupplier.hpp>
 #include <com/sun/star/form/XForm.hpp>
 #include <com/sun/star/lang/XServiceInfo.hpp>
@@ -59,7 +59,7 @@ namespace xmloff
     using namespace ::com::sun::star::table;
     using namespace ::com::sun::star::form;
     using namespace ::com::sun::star::lang;
-    using namespace ::drafts::com::sun::star::form;
+    using namespace ::com::sun::star::form::binding;
 
     namespace
     {
@@ -125,7 +125,7 @@ namespace xmloff
     }
 
     //------------------------------------------------------------------------
-    bool FormCellBindingHelper::convertStringAddress( const ::rtl::OUString& _rAddressDescription, CellAddress& /* [out] */ _rAddress, sal_Int16 _nAssumeSheet ) const
+    bool FormCellBindingHelper::convertStringAddress( const ::rtl::OUString& _rAddressDescription, CellAddress& /* [out] */ _rAddress, sal_Int16 /*_nAssumeSheet*/ ) const
     {
         Any aAddress;
         return doConvertAddressRepresentations(
@@ -218,7 +218,7 @@ namespace xmloff
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "FormCellBindingHelper::getStringAddressFromCellBinding: caught an exception!" );
+            OSL_FAIL( "FormCellBindingHelper::getStringAddressFromCellBinding: caught an exception!" );
         }
 
         return sAddress;
@@ -247,7 +247,7 @@ namespace xmloff
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "FormCellBindingHelper::getStringAddressFromCellListSource: caught an exception!" );
+            OSL_FAIL( "FormCellBindingHelper::getStringAddressFromCellListSource: caught an exception!" );
         }
 
         return sAddress;
@@ -283,7 +283,7 @@ namespace xmloff
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "FormCellBindingHelper::isSpreadsheetDocumentWhichSupplies: caught an exception!" );
+            OSL_FAIL( "FormCellBindingHelper::isSpreadsheetDocumentWhichSupplies: caught an exception!" );
         }
 
         return bYesItIs;
@@ -438,7 +438,7 @@ namespace xmloff
             }
             catch ( const Exception& )
             {
-                OSL_ENSURE( sal_False, "FormCellBindingHelper::createDocumentDependentInstance: could not create the binding at the document!" );
+                OSL_FAIL( "FormCellBindingHelper::createDocumentDependentInstance: could not create the binding at the document!" );
             }
         }
         return xReturn;
@@ -469,7 +469,7 @@ namespace xmloff
             }
             catch( const Exception& )
             {
-                OSL_ENSURE( sal_False, "FormCellBindingHelper::doConvertAddressRepresentations: caught an exception!" );
+                OSL_FAIL( "FormCellBindingHelper::doConvertAddressRepresentations: caught an exception!" );
             }
         }
 
