@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,8 +26,6 @@
  *
  ************************************************************************/
 
-/* $Id: hwpread.cpp,v 1.5 2008-04-10 12:10:14 rt Exp $ */
-
 #include "precompile.h"
 
 #include "list.hxx"
@@ -51,7 +50,7 @@ int HBox::Read(HWPFile & )
 
 // skip block
 
-int SkipBlock::Read(HWPFile & hwpf)
+int SkipData::Read(HWPFile & hwpf)
 {
     hwpf.Read4b(&data_block_len, 1);
     hwpf.Read2b(&dummy, 1);
@@ -811,3 +810,5 @@ int FixedSpace::Read(HWPFile & hwpf)
      }
     return !hwpf.State();
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
