@@ -29,9 +29,6 @@
 #include "oox/core/xmlfilterbase.hxx"
 
 #include <cstdio>
-
-#include <rtl/strbuf.hxx>
-#include <rtl/ustrbuf.hxx>
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/embed/XRelationshipAccess.hpp>
 #include <com/sun/star/xml/sax/InputSource.hpp>
@@ -39,49 +36,16 @@
 #include <com/sun/star/document/XDocumentProperties.hpp>
 #include <comphelper/mediadescriptor.hxx>
 #include <sax/fshelper.hxx>
-#include "properties.hxx"
-#include "tokens.hxx"
+#include <rtl/strbuf.hxx>
+#include <rtl/ustrbuf.hxx>
+#include "oox/core/fastparser.hxx"
+#include "oox/core/filterdetect.hxx"
+#include "oox/core/fragmenthandler.hxx"
+#include "oox/core/recordparser.hxx"
+#include "oox/core/relationshandler.hxx"
 #include "oox/helper/containerhelper.hxx"
 #include "oox/helper/propertyset.hxx"
 #include "oox/helper/zipstorage.hxx"
-#include "oox/core/fasttokenhandler.hxx"
-#include "oox/core/filterdetect.hxx"
-#include "oox/core/fragmenthandler.hxx"
-#include "oox/core/namespaces.hxx"
-#include "oox/core/recordparser.hxx"
-#include "oox/core/relationshandler.hxx"
-
-using ::rtl::OStringBuffer;
-using ::rtl::OUString;
-using ::rtl::OUStringBuffer;
-using ::com::sun::star::beans::StringPair;
-using ::com::sun::star::uno::Reference;
-using ::com::sun::star::uno::Sequence;
-using ::com::sun::star::uno::Exception;
-using ::com::sun::star::uno::RuntimeException;
-using ::com::sun::star::uno::UNO_QUERY;
-using ::com::sun::star::uno::UNO_QUERY_THROW;
-using ::com::sun::star::uno::UNO_SET_THROW;
-using ::com::sun::star::lang::Locale;
-using ::com::sun::star::lang::XMultiServiceFactory;
-using ::com::sun::star::embed::XRelationshipAccess;
-using ::com::sun::star::embed::XStorage;
-using ::com::sun::star::io::XInputStream;
-using ::com::sun::star::io::XOutputStream;
-using ::com::sun::star::io::XStream;
-using ::com::sun::star::container::XNameContainer;
-using ::com::sun::star::xml::sax::XFastParser;
-using ::com::sun::star::xml::sax::XFastTokenHandler;
-using ::com::sun::star::xml::sax::XFastDocumentHandler;
-using ::com::sun::star::xml::sax::InputSource;
-using ::com::sun::star::xml::sax::SAXException;
-using ::com::sun::star::document::XDocumentProperties;
-using ::com::sun::star::util::DateTime;
-using ::comphelper::MediaDescriptor;
-using ::sax_fastparser::FastSerializerHelper;
-using ::sax_fastparser::FSHelperPtr;
-
-
 #include <com/sun/star/document/XDocumentPropertiesSupplier.hpp>
 #include <com/sun/star/document/XOOXMLDocumentPropertiesImporter.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
@@ -89,17 +53,38 @@ using ::sax_fastparser::FSHelperPtr;
 #include <comphelper/mediadescriptor.hxx>
 #include <oox/core/filterdetect.hxx>
 #include <comphelper/storagehelper.hxx>
-
 using ::com::sun::star::uno::XComponentContext;
 using ::com::sun::star::document::XOOXMLDocumentPropertiesImporter;
 using ::com::sun::star::document::XDocumentPropertiesSupplier;
 using ::com::sun::star::beans::XPropertySet;
 using ::com::sun::star::lang::XComponent;
 
-
 namespace oox {
 namespace core {
 
+// ============================================================================
+
+using namespace ::com::sun::star::beans;
+using namespace ::com::sun::star::container;
+using namespace ::com::sun::star::document;
+using namespace ::com::sun::star::embed;
+using namespace ::com::sun::star::io;
+using namespace ::com::sun::star::lang;
+using namespace ::com::sun::star::uno;
+using namespace ::com::sun::star::util;
+using namespace ::com::sun::star::xml::sax;
+
+using ::comphelper::MediaDescriptor;
+using ::rtl::OStringBuffer;
+using ::rtl::OUString;
+using ::rtl::OUStringBuffer;
+using ::sax_fastparser::FSHelperPtr;
+using ::sax_fastparser::FastSerializerHelper;
+
+
+
+
+
 // ============================================================================
 
 namespace {
@@ -118,23 +103,47 @@ struct XmlFilterBaseImpl
 {
     typedef RefMap< OUString, Relations > RelationsMap;
 
-    Reference< XFastParser > mxFastParser;
-    OUString            maBinSuffix;
-    OUString            maVmlSuffix;
+    FastParser          maFastParser;
+    const OUString      maBinSuffix;
+    const OUString      maVmlSuffix;
     RelationsMap        maRelationsMap;
     TextFieldStack      maTextFieldStack;
-    explicit            XmlFilterBaseImpl();
+
+    explicit            XmlFilterBaseImpl( const Reference< XComponentContext >& rxContext ) throw( RuntimeException );
 };
 
 // ----------------------------------------------------------------------------
 
-XmlFilterBaseImpl::XmlFilterBaseImpl() :
+XmlFilterBaseImpl::XmlFilterBaseImpl( const Reference< XComponentContext >& rxContext ) throw( RuntimeException ) :
+    maFastParser( rxContext ),
     maBinSuffix( CREATE_OUSTRING( ".bin" ) ),
     maVmlSuffix( CREATE_OUSTRING( ".vml" ) )
 {
+    // register XML namespaces
+    maFastParser.registerNamespace( NMSP_xml );
+    maFastParser.registerNamespace( NMSP_packageRel );
+    maFastParser.registerNamespace( NMSP_officeRel );
+
+    maFastParser.registerNamespace( NMSP_dml );
+    maFastParser.registerNamespace( NMSP_dmlDiagram );
+    maFastParser.registerNamespace( NMSP_dmlChart );
+    maFastParser.registerNamespace( NMSP_dmlChartDr );
+    maFastParser.registerNamespace( NMSP_dmlSpreadDr );
+
+    maFastParser.registerNamespace( NMSP_vml );
+    maFastParser.registerNamespace( NMSP_vmlOffice );
+    maFastParser.registerNamespace( NMSP_vmlWord );
+    maFastParser.registerNamespace( NMSP_vmlExcel );
+    maFastParser.registerNamespace( NMSP_vmlPowerpoint );
+
+    maFastParser.registerNamespace( NMSP_xls );
+    maFastParser.registerNamespace( NMSP_ppt );
+
+    maFastParser.registerNamespace( NMSP_ax );
+    maFastParser.registerNamespace( NMSP_xm );
 }
 
-// ============================================================================
+
 static Reference< XComponentContext > lcl_getComponentContext(Reference< XMultiServiceFactory > aFactory)
 {
     Reference< XComponentContext > xContext;
@@ -142,7 +151,7 @@ static Reference< XComponentContext > lcl_getComponentContext(Reference< XMultiS
     {
         Reference< XPropertySet > xFactProp( aFactory, UNO_QUERY );
         if( xFactProp.is() )
-            xFactProp->getPropertyValue( OUString::createFromAscii("DefaultContext") ) >>= xContext;
+            xFactProp->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("DefaultContext")) ) >>= xContext;
     }
     catch( Exception& )
     {}
@@ -152,44 +161,14 @@ static Reference< XComponentContext > lcl_getComponentContext(Reference< XMultiS
 
 // ============================================================================
 
-XmlFilterBase::XmlFilterBase( const Reference< XMultiServiceFactory >& rxGlobalFactory ) :
-    FilterBase( rxGlobalFactory ),
-    mxImpl( new XmlFilterBaseImpl ),
+// ============================================================================
+
+XmlFilterBase::XmlFilterBase( const Reference< XComponentContext >& rxContext ) throw( RuntimeException ) :
+    FilterBase( rxContext ),
+    mxImpl( new XmlFilterBaseImpl( rxContext ) ),
     mnRelId( 1 ),
     mnMaxDocId( 0 )
 {
-    try
-    {
-        // create the fast parser
-        mxImpl->mxFastParser.set( rxGlobalFactory->createInstance( CREATE_OUSTRING( "com.sun.star.xml.sax.FastParser" ) ), UNO_QUERY_THROW );
-        mxImpl->mxFastParser->setTokenHandler( new FastTokenHandler );
-
-        // register XML namespaces
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "http://www.w3.org/XML/1998/namespace" ), NMSP_XML );
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "http://schemas.openxmlformats.org/package/2006/relationships" ), NMSP_PACKAGE_RELATIONSHIPS );
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "http://schemas.openxmlformats.org/officeDocument/2006/relationships" ), NMSP_RELATIONSHIPS );
-
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "http://schemas.openxmlformats.org/drawingml/2006/main" ), NMSP_DRAWINGML );
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "http://schemas.openxmlformats.org/drawingml/2006/diagram" ), NMSP_DIAGRAM );
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "http://schemas.openxmlformats.org/drawingml/2006/chart" ), NMSP_CHART );
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "http://schemas.openxmlformats.org/drawingml/2006/chartDrawing" ), NMSP_CDR );
-
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "urn:schemas-microsoft-com:vml" ), NMSP_VML );
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "urn:schemas-microsoft-com:office:office" ), NMSP_OFFICE );
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "urn:schemas-microsoft-com:office:word" ), NMSP_VML_DOC );
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "urn:schemas-microsoft-com:office:excel" ), NMSP_VML_XLS );
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "urn:schemas-microsoft-com:office:powerpoint" ), NMSP_VML_PPT );
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "http://schemas.microsoft.com/office/2006/activeX" ), NMSP_AX );
-
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "http://schemas.openxmlformats.org/spreadsheetml/2006/main"), NMSP_XLS );
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "http://schemas.openxmlformats.org/drawingml/2006/spreadsheetDrawing" ), NMSP_XDR );
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "http://schemas.microsoft.com/office/excel/2006/main" ), NMSP_XM );
-
-        mxImpl->mxFastParser->registerNamespace( CREATE_OUSTRING( "http://schemas.openxmlformats.org/presentationml/2006/main"), NMSP_PPT );
-    }
-    catch( Exception& )
-    {
-    }
 }
 
 XmlFilterBase::~XmlFilterBase()
@@ -200,13 +179,13 @@ XmlFilterBase::~XmlFilterBase()
 
 void XmlFilterBase::importDocumentProperties() throw()
 {
-    Reference< XMultiServiceFactory > xFactory( getGlobalFactory(), UNO_QUERY );
+    Reference< XMultiServiceFactory > xFactory( getServiceFactory(), UNO_QUERY );
     MediaDescriptor aMediaDesc( getMediaDescriptor() );
     Reference< XInputStream > xInputStream;
-    ::oox::core::FilterDetect aDetector( xFactory );
+    Reference< XComponentContext > xContext = lcl_getComponentContext(getServiceFactory());
+    ::oox::core::FilterDetect aDetector( xContext );
     xInputStream = aDetector.extractUnencryptedPackage( aMediaDesc );
     Reference< XComponent > xModel( getModel(), UNO_QUERY );
-    Reference< XComponentContext > xContext = lcl_getComponentContext(getGlobalFactory());
     Reference< XStorage > xDocumentStorage (
             ::comphelper::OStorageHelper::GetStorageOfFormatFromInputStream( OFOPXML_STORAGE_FORMAT_STRING, xInputStream ) );
     Reference< XInterface > xTemp = xContext->getServiceManager()->createInstanceWithContext(
@@ -265,30 +244,25 @@ bool XmlFilterBase::importFragment( const ::rtl::Reference< FragmentHandler >& r
     if( !xDocHandler.is() )
         return false;
 
-    // check that the fast parser exists
-    if( !mxImpl->mxFastParser.is() )
-        return false;
-
     // try to import XML stream
     try
     {
-        // try to open the fragment stream (this may fail - do not assert)
-        Reference< XInputStream > xInStrm( rxHandler->openFragmentStream(), UNO_SET_THROW );
+        /*  Try to open the fragment stream (may fail, do not throw/assert).
+            Using the virtual function openFragmentStream() allows a document
+            handler to create specialized input streams, e.g. VML streams that
+            have to preprocess the raw input data. */
+        Reference< XInputStream > xInStrm = rxHandler->openFragmentStream();
 
-        // create the input source and parse the stream
-        InputSource aSource;
-        aSource.aInputStream = xInStrm;
-        aSource.sSystemId = aFragmentPath;
         // own try/catch block for showing parser failure assertion with fragment path
-        try
+        if( xInStrm.is() ) try
         {
-            mxImpl->mxFastParser->setFastDocumentHandler( xDocHandler );
-            mxImpl->mxFastParser->parseStream( aSource );
+            mxImpl->maFastParser.setDocumentHandler( xDocHandler );
+            mxImpl->maFastParser.parseStream( xInStrm, aFragmentPath );
             return true;
         }
         catch( Exception& )
         {
-            OSL_ENSURE( false, OStringBuffer( "XmlFilterBase::importFragment - XML parser failed in fragment '" ).
+            OSL_FAIL( OStringBuffer( "XmlFilterBase::importFragment - XML parser failed in fragment '" ).
                 append( OUStringToOString( aFragmentPath, RTL_TEXTENCODING_ASCII_US ) ).append( '\'' ).getStr() );
         }
     }
@@ -321,7 +295,11 @@ Reference< XOutputStream > XmlFilterBase::openFragmentStream( const OUString& rS
 
 FSHelperPtr XmlFilterBase::openFragmentStreamWithSerializer( const OUString& rStreamName, const OUString& rMediaType )
 {
-    return FSHelperPtr( new FastSerializerHelper( openFragmentStream( rStreamName, rMediaType ) ) );
+    bool bWriteHeader = true;
+    if( rMediaType.indexOfAsciiL( "vml", 3 ) >= 0 &&
+        rMediaType.indexOfAsciiL( "+xml", 4 ) < 0 )
+        bWriteHeader = false;
+    return FSHelperPtr( new FastSerializerHelper( openFragmentStream( rStreamName, rMediaType ), bWriteHeader ) );
 }
 
 TextFieldStack& XmlFilterBase::getTextFieldStack() const
@@ -572,7 +550,7 @@ Reference< XInputStream > XmlFilterBase::implGetInputStream( MediaDescriptor& rM
     /*  Get the input stream directly from the media descriptor, or decrypt the
         package again. The latter is needed e.g. when the document is reloaded.
         All this is implemented in the detector service. */
-    FilterDetect aDetector( getGlobalFactory() );
+    FilterDetect aDetector( getComponentContext() );
     return aDetector.extractUnencryptedPackage( rMediaDesc );
 }
 
@@ -580,12 +558,12 @@ Reference< XInputStream > XmlFilterBase::implGetInputStream( MediaDescriptor& rM
 
 StorageRef XmlFilterBase::implCreateStorage( const Reference< XInputStream >& rxInStream ) const
 {
-    return StorageRef( new ZipStorage( getGlobalFactory(), rxInStream ) );
+    return StorageRef( new ZipStorage( getServiceFactory(), rxInStream ) );
 }
 
 StorageRef XmlFilterBase::implCreateStorage( const Reference< XStream >& rxOutStream ) const
 {
-    return StorageRef( new ZipStorage( getGlobalFactory(), rxOutStream ) );
+    return StorageRef( new ZipStorage( getServiceFactory(), rxOutStream ) );
 }
 
 // ============================================================================
